
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.2.96'
version = '1.2.96'
full_version = '1.2.96'
git_revision = 'fa73f975aa15adeda5ab8b010b70831e027ae524'
release = True

if not release:
    version = full_version
    short_version += ".dev"
